(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59699,       1776]*)
(*NotebookOutlinePosition[     87901,       2456]*)
(*  CellTagsIndexPosition[     84468,       2371]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Demo: Predicate Logic Proving", "Title"],

Cell[CellGroupData[{

Cell["Note on the Predicate Logic Prover", "Subsection"],

Cell["\<\
This is a preliminary version of the prover, which is able to handle only a \
part of the provable formulae - in particular those which allow deduction \
based on ground atomic instances. The emphasis in this version of the prover \
is neither on completeness nor on speed, but on using deduction rules which \
are as natural as possible. Also, the prover does not use a separate engine \
for searching the possible proof, therefore all the formulae generated during \
the search are displayed, even if some of them are not needed for the final \
result.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Starting the System", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(<< Theorema`\ \)\)], "Input"],

Cell[BoxData[
    \("You can specify your personal preferences in a file `Setup.m` in the \
directory (folder) \"Theorema -> User\" in your private Theorema \
directory!"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "The following command sets the PredicateProver as the default prover to be \
used in the command ",
  StyleBox["Prove",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(SetGlobals[Prover \[Rule] PredicateProver]\)], "Input"],

Cell["Some of the proofs in this demo require a higher value:", "Text"],

Cell[BoxData[
    \(\($RecursionLimit = 1024; \)\)], "Input"],

Cell["\<\
Each of the following commands controls the appearance of the labels in the \
generated proofs.\
\>", "Text"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Alphanumeric\>"]\)], "Input"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Numeric\>"]\)], "Input"],

Cell["Setting the global status of the system:", "Text"],

Cell[BoxData[
    \(SetGlobals[SearchDepth \[Rule] 100]\)], "Input"],

Cell[BoxData[
    \(SetGlobals[DebugLevel \[Rule] 0]\)], "Input"],

Cell[BoxData[
    \(SetGlobals[TraceLevel \[Rule] 0]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Options of the Predicate Prover, Using Equality", "Section"],

Cell["\<\
All the options of the propositional prover are also available for the \
predicate logic prover:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[PredicateProver]\)], "Input"],

Cell[BoxData[
    \({TryAlternatives \[Rule] False, BackChaining \[Rule] False, 
      BackChainingDisjunction \[Rule] False, 
      BackChainingImplication \[Rule] False, 
      BackChainingEquivalence \[Rule] False, 
      TrySubgoalImplication \[Rule] False, 
      TrySubgoalEquivalence \[Rule] False, TrySubgoal \[Rule] False, 
      PNDLevel \[Rule] 1, PNDNoEquality \[Rule] False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[PND]\)], "Input"],

Cell[BoxData[
    \({TryAlternatives \[Rule] False, BackChaining \[Rule] False, 
      BackChainingDisjunction \[Rule] False, 
      BackChainingImplication \[Rule] False, 
      BackChainingEquivalence \[Rule] False, 
      TrySubgoalImplication \[Rule] False, 
      TrySubgoalEquivalence \[Rule] False, TrySubgoal \[Rule] False, 
      PNDLevel \[Rule] 1, PNDNoEquality \[Rule] False}\)], "Output"]
}, Open  ]],

Cell["\<\
The additional options specific to predicate proving are described below.\
\>", "Text"],

Cell[CellGroupData[{

Cell["PND Level", "Subsection"],

Cell["PND stands for \"Prove by Natural Deduction\".", "Text"],

Cell["\<\
PNDLevel controls the \"cleverness\" of the predicate logic prover. When the \
level is higher, more sofisticated rules are applied. The default value is 1.\
\
\>", "Text"],

Cell[BoxData[
    RowBox[{"Theorem", "[", 
      RowBox[{"\"\<D\>\"", ",", GridBox[{
            {
              \(\((\((\[ForAll] \+x P[x])\) \[Implies] Q)
                  \)\[DoubleLongRightArrow]\((
                  \[Exists] \+x\((P[x] \[Implies] Q)\))\)\), "\"\<d\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"D"],

Cell[BoxData[
    \(Prove[Theorem["\<D\>"]]\)], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "PND-clever.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    \(Prove[Theorem["\<D\>"], ProverOptions \[Rule] {PNDLevel -> 0}]\)], 
  "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "PND-nclever.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell["\<\
Currently the effect of the PNDLevel option is the following:\
\>", "Text"],

Cell["      PNDLevel  >  0: ", "Text"],

Cell["\<\
        - in universal assumptions of of type disjunction, implication, and \
equivalence, check whether the quantified variables occur in all operands and \
move the universal quantifier inside the formula when possible;\
\>", "Text"],

Cell["\<\
        - transform existential goal which is an implication or an \
equivalence into a disjunction.\
\>", "Text"],

Cell["      PNDLevel  >  1: ", "Text"],

Cell[TextData[{
  "- transform existential goal of type ",
  StyleBox["\[Exists] (f \[DoubleLeftRightArrow] g)",
    FontWeight->"Bold"],
  " into ",
  StyleBox["\[ForAll]f \[Implies] \[Exists]g",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "- transform existential goal of type ",
  StyleBox["\[Exists] (f \[Implies] g)",
    FontWeight->"Bold"],
  " into ",
  StyleBox["\[ForAll]f \[Implies] \[Exists]g",
    FontWeight->"Bold"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using Equality", "Subsection"],

Cell["\<\
In the current version of the predicate logic prover, equalities are used for \
rewriting left-to-right the [sub]terms occuring in the goal. (The user should \
be aware that [ab]using equalities may lead to infinite loops!)\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Sum of functions is commutative\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, g, x\)\((
                  \((f\[CirclePlus]g)\)[x] = \((g\[CirclePlus]f)\)[x])\)\), 
              "\"\<fg\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "Sum of functions is commutative"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, g, x\)\((
                  \((f\[CirclePlus]g)\)[x] = \((f[x] + g[x])\))\)\), 
              "\"\<d+\>\""},
            {\(\[ForAll] \+\(x, y\)\((x + y = y + x)\)\), "\"\<c+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "Sum"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Theorem",
            FontWeight->"Bold"], "[", 
          "\"\<Sum of functions is commutative\>\"", "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Theory",
              FontWeight->"Bold"], "[", "\"\<Sum\>\"", "]"}]}]}], "]"}]], 
  "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "fg-circle-sum=.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell["\<\
The option PNDNoEquality disables this deduction rules - the rewriting is not \
done anymore.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Theorem",
            FontWeight->"Bold"], "[", 
          "\"\<Sum of functions is commutative\>\"", "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Theory",
              FontWeight->"Bold"], "[", "\"\<Sum\>\"", "]"}]}], ",", 
        \(ProverOptions \[Rule] {PNDNoEquality \[Rule] True}\)}], "]"}]], 
  "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "fg-circle-sum.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[{
  "Additionally, the prover handles the symbol \":=\" as ",
  StyleBox["equivalent by definition. ",
    FontSlant->"Italic"],
  "The formulae matching such a definition will be rewritten (again \
left-to-right) both in the goal and in the assumptions, but only when they \
occur at top level - s",
  "ee examples in the sections Symmetric Difference and Limit of Sum below."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Propositional Proving ", "Section"],

Cell[BoxData[
    \(See\ Demo/PropositionalDemo . nb\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetric Difference", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<symmetric difference\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x\[CircleMinus]y)\) := 
                    \((\((x \[And] \((\[Not] y)\))\) \[Or] 
                        \((\((\[Not] x)\) \[And] y)\))\))\)\), 
              "\"\<\[CircleMinus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "symmetric difference"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<associativity of symmetric difference right\>\"", ",", "\n", "\t", 
        GridBox[{
            {
              \(\((\((A\[CircleMinus]B)\)\[CircleMinus]C)
                  \)\[DoubleLongRightArrow]\((
                  A\[CircleMinus]\((B\[CircleMinus]C)\))\)\), 
              "\"\<\[DoubleLongRightArrow]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "associativity of symmetric difference", 
    "associativity of symmetric difference right", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
      \(Proposition["\<associativity of symmetric difference right\>"]\), 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Definition",
              FontWeight->"Bold"], "[", "\"\<symmetric difference\>\"", 
            "]"}]}]}], "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "symmetric-dif-right.nb", 
      CharacterEncoding -> "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<associativity of symmetric difference left\>\"", ",", "\n", "\t", 
        GridBox[{
            {
              \(\((\((A\[CircleMinus]B)\)\[CircleMinus]C)
                  \)\[DoubleLongLeftArrow]\((
                  A\[CircleMinus]\((B\[CircleMinus]C)\))\)\), 
              "\"\<\[DoubleLongLeftArrow]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "associativity of symmetric difference", 
    "associativity of symmetric difference left", "Iterated Implication"}],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "symmetric-dif-left.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quantified Theorems on Implication", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<ForAll Distributivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\[ForAll] \+x\((P[x]\[DoubleLongRightArrow]Q)\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \((\[Exists] \+y P[y])\)\[DoubleLongRightArrow]Q)\)\), 
              "\"\<\[ForAll]d\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"ForAll Distributivity", "Quantifier Distributivity"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      \(Proposition["\<ForAll Distributivity\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<ForAll Distributivity\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}, 
      presentation \[Rule] "\<SuccessBranch\>"\), "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "FA-Distrib.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<ForAll Distributivity\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 0}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Theorem", "[", 
      RowBox[{"\"\<Exists Distributivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\((\[ForAll] \+x P[x])\) \[Implies] Q)\) 
                \[DoubleLeftRightArrow] 
                \((\[Exists] \+y\((P[y] \[Implies] Q)\))\)\), 
              "\"\<\[Exists]d\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"D", "Exists Distributivity"}],

Cell[BoxData[
    \(Prove[Theorem["\<Exists Distributivity\>"]]\)], "Input"],

Cell[BoxData[
    \(Prove[Theorem["\<Exists Distributivity\>"], 
      ProverOptions \[Rule] {PNDLevel -> 0, BackChaining \[Rule] True}, 
      presentation \[Rule] "\<SuccessBranch\>"]\)], "Input"],

Cell[BoxData[
    \(Prove[Theorem["\<Exists Distributivity\>"], 
      ProverOptions \[Rule] {PNDLevel -> 2, BackChaining \[Rule] True}, 
      presentation \[Rule] "\<SuccessBranch\>"]\)], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "EX-Distrib.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p1\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\[Exists] \+x\((P[x]\[DoubleLongRightArrow]Q[x])\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \((\[ForAll] \+y P[y])\)\[DoubleLongRightArrow]\((
                      \[Exists] \+z Q[z])\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "p1"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p1\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p1\>"], 
      ProverOptions \[Rule] {PNDLevel -> 0}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p2\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\[ForAll] \+\(x, y\)\((P[x]\[DoubleLongRightArrow]Q[y])\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \((\[Exists] \+z P[z])\)\[DoubleLongRightArrow]\((
                      \[ForAll] \+t Q[t])\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "p2"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p2\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p2\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p3\>\"", ",", "\n", "\t    ", GridBox[{
            {
              \(\((\[ForAll] \+x\((
                      \[Not] \((P[x]\[DoubleLongLeftRightArrow]Q[x])\))\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \[ForAll] \+y\((
                      \((\[Not] P[y])\)\[DoubleLongLeftRightArrow]Q[y])\))
                  \)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"p", "p3", "Peirce Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p3\>"]\), "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "P3.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p3\>"], 
      ProverOptions \[Rule] {PNDLevel -> 0}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p4\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\[Exists] \+x\((P[x]\[DoubleLongLeftRightArrow]Q[x])\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \((\[ForAll] \+y\((P[y] \[Or] Q[y])\))
                      \)\[DoubleLongRightArrow]\((
                      \[Exists] \+z\((P[z] \[And] Q[z])\))\))\)\), 
              "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "p4"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"], 
      ProverOptions \[Rule] {PNDLevel -> 0}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"], 
      ProverOptions \[Rule] {PNDLevel -> 0}, 
      presentation \[Rule] "\<SuccessBranch\>"\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"], 
      ProverOptions \[Rule] {PNDLevel -> 2}\), "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "P4.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p5\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\[ForAll] \+y\((P[y]\[DoubleLongLeftRightArrow]Q[y])\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \[ForAll] \+x\((
                      \((P[x] \[And] Q[x])\) \[Or] 
                        \((\((\[Not] P[x])\) \[And] \((\[Not] Q[x])\))\))\))
                  \)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Iterated Implication", "p5"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p5\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p6\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\((\[ForAll] \+y\((P[y]\[DoubleLongLeftRightArrow]Q[y])\))
                  \)\[DoubleLongLeftRightArrow]\((
                  \((\[ForAll] \+x\((P[x] \[Or] \((\[Not] Q[x])\))\))\) 
                    \[And] \((\[ForAll] \+x\((\((\[Not] P[x])\) \[Or] Q[x])\))
                      \))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Iterated Implication"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p6\>"]\), "]"}]], "Input",
  CellTags->"ForAll Distributivity"]
}, Closed]],

Cell[CellGroupData[{

Cell["Equality, Order, Congruence", "Section"],

Cell[CellGroupData[{

Cell["Equal", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal Reflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\((x = x)\)\), "\"\<=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal Reflexivity", "Equal\[Dash]Reflexivity", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal Symmetry\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x = y)\)\[DoubleLongRightArrow]\((y = x)\))\)\), 
              "\"\<=\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal Reflexivity", "Equal Symmetry", "Equal\[Dash]Symmetry", 
    "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y, z\)\((
                  \((\((x = y)\)\  \[And] \ \((y = z)\))
                      \)\[DoubleLongRightArrow]\ \((x = z)\))\)\), 
              "\"\<==\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal Transitivity", "Equal\[Dash]Transitivity", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", "]"}], 
      "]"}]], "Input"],

Cell["\<\
The proof above succeed because the built-in mecanism of the prover which \
replaces terms using equalities as left-to-right rewrite rules. However, when \
studying the properties of the equality starting from its axioms, we do not \
want to apply this mechanism:\
\>", "Text"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", "]"}], 
        ",", \(ProverOptions \[Rule] {PNDNoEquality \[Rule] True}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equal Transitivity \[Exists]\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, z\)\((
                  \((\[Exists] \+y\((\((x = y)\)\  \[And] \ \((y = z)\))\))
                      \)\[DoubleLongRightArrow]\ \((x = z)\))\)\), 
              "\"\<\[Exists]==\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal Transitivity \[Exists]", "Equal\[Dash]Transitivity", 
    "Equal\[Dash]Transitivity\[Dash]\[Exists]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", 
            "\"\<Equal Transitivity \[Exists]\>\"", "]"}]}], ",", 
        \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, BackChaining \[Rule] True}
            \)}], "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "eq-trans-ex.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equal Transitivity \[ForAll]\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x = y)\)\ 
                    \[DoubleLongRightArrow]\((
                      \[ForAll] \+z\((\ 
                          \((y = z)\)\[DoubleLongRightArrow]\ \((x = z)\))\))
                      \))\)\), "\"\<=\[Implies]\[ForAll]=\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
    "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
    "Equal\[Dash]Transitivity\[Dash]\[ForAll]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", 
            "\"\<Equal Transitivity \[ForAll]\>\"", "]"}]}], ",", 
        \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, BackChaining \[Rule] True}
            \)}], "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "eq-trans-fa.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Reflexivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Symmetry\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", 
                "]"}]}
            }]}], "]"}]], "Input",
  CellTags->{"Equal", "Equality", "Iterated Implication"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Less", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less Irreflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\(\[Not] \((x\  < \ x)\)\)\), "\"\<\[Not]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "Less Irreflexivity", "Less\[Dash]Irreflexivity"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less Antisymmetry\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x\  < y)\)\[DoubleLongRightArrow]\(\[Not] 
                      \((y\  < \ x)\)\))\)\), "\"\<<\[Implies]\[Not]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "Less Antisymmetry", "Less\[Dash]Antisymmetry"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", 
            "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y, z\)\((
                  \((\((x\  < \ y)\) \[And] \((y < z)\))
                      \)\[DoubleLongRightArrow]\((x\  < \ z)\))\)\), 
              "\"\<<<\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "Less Transitivity", "Less\[Dash]Transitivity"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}], ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", 
                "]"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Less Transitivity \[Exists]\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, z\)\((
                  \((\[Exists] \+y\((\((x\  < \ y)\) \[And] \((y < z)\))\))
                      \)\[DoubleLongRightArrow]\((x\  < \ z)\))\)\), 
              "\"\<<<\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "Less Transitivity \[Exists]", 
    "Less\[Dash]Transitivity\[Dash]\[Exists]"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", 
            "\"\<Less Transitivity \[Exists]\>\"", "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", 
            "\"\<Less Transitivity \[Exists]\>\"", "]"}]}], ",", 
        \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
        \(ProverOptions \[Rule] {BackChaining \[Rule] True}\)}], "]"}]], 
  "Input",
  CellTags->"Less\[Dash]Transitivity\[Dash]\[Exists]"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Transitivity \[Exists]\>\"", 
          "]"}], ",", 
        \(using \[Rule] Proposition["\<Less Transitivity\>"]\)}], "]"}]], 
  "Input"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Transitivity \[Exists]\>\"", 
          "]"}], ",", \(using \[Rule] Proposition["\<Less Transitivity\>"]\), 
        ",", \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
        \(ProverOptions 
          \[Rule] {PNDLevel \[Rule] 0, BackChaining \[Rule] True}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}]}
            }]}], "]"}]], "Input",
  CellTags->{"Equality", "Iterated Implication", "Less"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Equal and Less", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal not Less\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x = y)\)\[DoubleLongRightArrow]\(\[Not] 
                      \((x\  < \ y)\)\))\)\), "\"\<=\[Implies]\[Not]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal not Less", "equal\[Dash]not\[Dash]less", 
    "Equal\[Dash]not\[Dash]Less", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal not Greater\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x = y)\)\[DoubleLongRightArrow]\(\[Not] 
                      \((y\  < \ x)\)\))\)\), "\"\<=\[Implies]\[Not]>\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
    "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
    "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Equal not Greater\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Symmetry\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal not Less\>\"", 
                "]"}]}], "}"}]}], ",", 
        \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, BackChaining \[Rule] True}
            \)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less and Equal Totality\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x < y)\) \[Or] \((\ x = y)\) \[Or] \((y < x)\))\)\), 
              "\"\<<\[Or]=\[Or]>\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "Less and Equal Totality", 
    "Less\[Dash]and\[Dash]Equal\[Dash]Totality", "Less\[Dash]Totality"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Less and Equal Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y, z\)\((
                  \((\((x\  < \ y)\) \[And] \((y = z)\))
                      \)\[DoubleLongRightArrow]\((x\  < \ z)\))\)\), 
              "\"\<<=\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "Less and Equal Transitivity", 
    "Less\[Dash]and\[Dash]Equal\[Dash]Transitivity"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equal and Less Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y, z\)\((
                  \((\((x = y)\) \[And] \((y < z)\))
                      \)\[DoubleLongRightArrow]\((x\  < \ z)\))\)\), 
              "\"\<=<\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Equal and Less Transitivity", 
    "Equal\[Dash]and\[Dash]Less\[Dash]Transitivity", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal versus Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal not Less\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal not Greater\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<Less and Equal Totality\>\"", "]"}]}
            }]}], "]"}]], "Input",
  CellTags->{
  "Equal and Less", "Equality", "Equal versus Less", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal and Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Equal\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Less\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Equal versus Less\>\"", 
                "]"}]}
            }]}], "]"}]], "Input",
  CellTags->{"Equal and Less", "Equality", "Iterated Implication"}]
}, Closed]],

Cell[CellGroupData[{

Cell["LessOrEqual", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Def\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x\  \[LessEqual] \ y)\) := \ 
                    \((\((x\  = y)\) \[Or] \((\ x\  < \ y)\))\))\)\), 
              "\"\<\[LessEqual]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Def", "LessOrEqual\[Dash]Def"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Reflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\((x\  \[LessEqual] \ x)\)\), 
              "\"\<\[LessEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Reflexivity", 
    "LessOrEqual\[Dash]Reflexivity"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<LessOrEqual Reflexivity\>\"", 
          "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<LessOrEqual Def\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Reflexivity\>\"", 
                "]"}]}], "}"}]}], ",", 
        \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, BackChaining \[Rule] True, 
            PNDLevel \[Rule] 0}\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Antisymmetry\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((\((x\  \[LessEqual] \ y)\) \[And] \((y \[LessEqual] x)\))
                      \)\[DoubleLongRightArrow]\((x = y)\))\)\), 
              "\"\<\[LessEqual]\[GreaterEqual]\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Antisymmetry", 
    "LessOrEqual\[Dash]antiSymmetry", "LessOrEqual\[Dash]Antisymmetry"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<LessOrEqual Antisymmetry\>\"", 
          "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<LessOrEqual Def\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Symmetry\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", 
                "]"}]}], "}"}]}], ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, PNDLevel \[Rule] 0}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y, z\)\((
                  \((\((x\  \[LessEqual] \ y)\) \[And] \((y \[LessEqual] z)\))
                      \)\[DoubleLongRightArrow]\((x\  \[LessEqual] \ z)\))
                  \)\), "\"\<\[LessEqual]\[LessEqual]\[Implies]\[LessEqual]\>\
\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Transitivity", 
    "LessOrEqual\[Dash]Transitivity"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<LessOrEqual Transitivity \[Exists]\>\"", ",", "\n", "\t", 
        GridBox[{
            {
              \(\[ForAll] \+\(x, z\)\((
                  \((\[Exists] \+y\((
                          \((x\  \[LessEqual] \ y)\) \[And] 
                            \((y \[LessEqual] z)\))\))
                      \)\[DoubleLongRightArrow]\((x\  \[LessEqual] \ z)\))
                  \)\), "\"\<\[Exists]\[LessEqual]\[LessEqual]\[Implies]\
\[LessEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual-Transitivity\[Dash]\[Exists]", 
    "LessOrEqual-Transitivity \[Exists]", 
    "LessOrEqual Transitivity \[Exists]"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<Equal and Less Transitivity\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<Less and Equal Transitivity\>\"", "]"}]}
            }]}], "]"}]], "Input",
  CellTags->{"Equal", "Equality", "Iterated Implication", "Transitivity"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Congruence", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Congruence Def by LessOrEqual\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x\  \[Tilde] \ y)\) := \ 
                    \((\((x\  \[LessEqual] \ y)\) \[And] 
                        \((y\  \[LessEqual] \ x)\))\))\)\), 
              "\"\<\[Tilde]:\[LessEqual]\[LessEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Congruence Def by LessOrEqual", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Congruence Reflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\((x\  \[Tilde] \ x)\)\), "\"\<\[Tilde]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Congruence Reflexivity", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Congruence Reflexivity\>\"", 
          "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", 
                "\"\<Congruence Def by LessOrEqual\>\"", "]"}], ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<LessOrEqual Reflexivity\>\"", "]"}]}], "}"}]}], ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, PNDLevel \[Rule] 0}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Congruence Symmetry\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y\)\((
                  \((x\  \[Tilde] y)\)\[DoubleLongRightArrow]\((
                      y\  \[Tilde] \ x)\))\)\), 
              "\"\<\[Tilde]\[Implies]\[Tilde]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Congruence Symmetry", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Congruence Symmetry\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Definition",
              FontWeight->"Bold"], "[", 
            "\"\<Congruence Def by LessOrEqual\>\"", "]"}]}], ",", 
        \(ProverOptions 
          \[Rule] {PNDNoEquality \[Rule] True, PNDLevel \[Rule] 0}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Congruence Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(x, y, z\)\((
                  \((\((x\  \[Tilde] \ y)\) \[And] \((y \[Tilde] z)\))
                      \)\[DoubleLongRightArrow]\((x\  \[Tilde] \ z)\))\)\), 
              "\"\<\[Tilde]\[Tilde]\[Implies]\[Tilde]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Congruence Transitivity", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Congruence Transitivity\>\"", 
            "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", 
                  "\"\<Congruence Def by LessOrEqual\>\"", "]"}], ",", 
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<LessOrEqual Transitivity\>\"", "]"}]}], "}"}]}], ",", 
          \(presentation \[Rule] "\<SuccessBranch\>"\), ",", 
          \(ProverOptions 
            \[Rule] {PNDNoEquality \[Rule] True, PNDLevel \[Rule] 0}\)}], 
        "]"}], "]"}]], "Input"],

Cell[TextData[ButtonBox["\tSee the proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "congr-trans.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The Limit of a Sum", "Section"],

Cell["\<\
In the spirit of \"structured programming\", we build the definition of limit \
up in a hierarchy of definitions, one quantifier at a time:\
\>", "Text"],

Cell["\<\
In these definitions the symbol \":=\" is used as \"equivalent by \
definition\".\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a\)\((
                  \((limit[f, a])\)\  := 
                    \((\ \[ForAll] \+\[Epsilon] limit[f, a, \[Epsilon]])\))
                  \)\), "\"\<l2:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Epsilon]\)\((
                  \((limit[f, a, \[Epsilon]])\) := \ 
                    \[Exists] \+N limit[f, a, \[Epsilon], N])\)\), 
              "\"\<l3:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Epsilon], N\)\((
                  \((limit[f, a, \[Epsilon], N])\) := 
                    \((\(\(\ \[ForAll] \)\+n\) 
                        \((n \[GreaterEqual] N)\)\[DoubleLongRightArrow]\((
                            \[LeftBracketingBar]f[n] - a
                                  \[RightBracketingBar] < \[Epsilon])\))\))
                  \)\), "\"\<l4:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell["Auxiliary knowledge:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum of sequences\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\((f\[CirclePlus]g)\)[x])\) = \((f[x] + g[x])\)\), 
              "\"\<\[CirclePlus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"sum of sequences"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of sum\>\"", ",", 
        \(any[x, y, a, b, \[Delta], \[Epsilon]]\), ",", "\n", "\t", GridBox[{
            {
              \(\((\[LeftBracketingBar]x - a\[RightBracketingBar] < \[Delta] 
                    \[And] \[LeftBracketingBar]y - b\[RightBracketingBar] < 
                      \[Epsilon])\)\[DoubleLongRightArrow]\((
                  \[LeftBracketingBar]\((x + y)\) - 
                        \((a + b)\)\[RightBracketingBar] < 
                    \[Delta] + \[Epsilon])\)\), 
              "\"\<\[LeftBracketingBar]++\[RightBracketingBar]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"distance of sum"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<max\>\"", ",", \(any[M, m, n]\), ",", "\n", "\t", GridBox[{
            {
              \(\((M \[GreaterEqual] max[m, n])\)\[DoubleLongRightArrow]\((
                  M \[GreaterEqual] m \[And] M \[GreaterEqual] n)\)\), 
              "\"\<max:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
    "sum of sequences"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<4-ary limit\>"]\)},
            {\(Definition["\<sum of sequences\>"]\)},
            {\(Proposition["\<distance of sum\>"]\)},
            {\(Proposition["\<max\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"4-ary limit"],

Cell["Ultimately, we want to prove", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<2-ary limit of sum\>\"", ",", \(any[f, a, g, b]\), ",", "\n", 
        "\t", GridBox[{
            {
              \(\((limit[f, a] \[And] limit[g, b])\)\n\t
                \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b]\), 
              "\"\<l2+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit of sum"],

Cell["\<\
The decomposition of the limit definition suggests building up the \
proposition (and its proof)  in a hierarchy of propositions (and proofs):\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Delta], M, g, b, \[Epsilon], N\)\((
                  \((limit[f, a, \[Delta], M] \[And] 
                        limit[g, b, \[Epsilon], N])\)\n\t
                    \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b, 
                      \[Delta] + \[Epsilon], max[M, N]])\)\), "\"\<l4+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"4-ary limit of sum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<4-ary limit of sum\>"], 
        using \[Rule] Theory["\<4-ary limit\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}], "]"}]], 
  "Input"],

Cell[BoxData[
    \({7.50100000000020372`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Open  ]],

Cell[TextData[ButtonBox["\tSee the Proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "limit-4.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    \(Show[$TmaProofObject]\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<3-ary limit\>"]\)},
            {\(Proposition["\<4-ary limit of sum\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Delta], g, b, \[Epsilon]\)\((
                  \((limit[f, a, \[Delta]] \[And] limit[g, b, \[Epsilon]])\)\n
                    \t\[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b, 
                      \[Delta] + \[Epsilon]])\)\), "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary limit of sum"],

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<3-ary limit of sum\>"], 
        using \[Rule] Theory["\<3-ary limit\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}, 
        presentation \[Rule] "\<SuccessBranch\>"\), "]"}], "]"}]], "Input"],

Cell[BoxData[
    \(ProofShow[]\)], "Input"],

Cell[TextData[ButtonBox["\tSee the Proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "limit-3.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<3-ary limit of sum\>"], 
        using \[Rule] Theory["\<3-ary limit\>"], 
        ProverOptions 
          \[Rule] {BackChaining \[Rule] True, PNDLevel \[Rule] 0}\), "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(Show[$TmaProofObject, presentation \[Rule] "\<SuccessBranch\>"]\)], 
  "Input"],

Cell[TextData[ButtonBox["\tSee the Proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "limit-3-bis.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<3-ary limit of sum: variant\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, g, b, \[Epsilon]\)\((
                  \((limit[f, a, \[Epsilon]/2] \[And] 
                        limit[g, b, \[Epsilon]/2])\)\n\t
                    \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b, 
                      \[Epsilon]])\)\), "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary limit of sum: variant"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<2-ary limit\>"]\)},
            {\(Proposition["\<3-ary limit of sum: variant\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, g, b\)\((
                  \((limit[f, a] \[And] limit[g, b])\)\n\t
                    \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b])
                  \)\), "\"\<l2+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit of sum"],

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<2-ary limit of sum\>"], 
        using \[Rule] Theory["\<2-ary limit\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}], "]"}]], 
  "Input"],

Cell[TextData[ButtonBox["\tSee the Proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "limit-2.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowToolbars->"EditBar",
WindowSize->{1005, 902},
WindowMargins->{{74, Automatic}, {Automatic, 71}},
Magnification->1.5,
StyleDefinitions -> "TheoremaTextbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "D"->{
    Cell[5368, 178, 365, 9, 58, "Input",
      CellTags->"D"],
    Cell[14802, 476, 446, 10, 98, "Input",
      CellTags->{"D", "Exists Distributivity"}]},
  "Iterated Implication"->{
    Cell[7622, 256, 484, 12, 85, "Input",
      CellTags->{"Iterated Implication", "Sum of functions is commutative"}],
    Cell[8109, 270, 486, 12, 132, "Input",
      CellTags->{"Iterated Implication", "Sum"}],
    Cell[10691, 356, 560, 13, 85, "Input",
      CellTags->{"Iterated Implication", "symmetric difference"}],
    Cell[11254, 371, 639, 16, 68, "Input",
      CellTags->{
      "associativity of symmetric difference", 
        "associativity of symmetric difference right", 
        "Iterated Implication"}],
    Cell[12501, 408, 635, 16, 68, "Input",
      CellTags->{
      "associativity of symmetric difference", 
        "associativity of symmetric difference left", 
        "Iterated Implication"}],
    Cell[15932, 507, 529, 12, 98, "Input",
      CellTags->{"Iterated Implication", "p1"}],
    Cell[16772, 532, 536, 12, 104, "Input",
      CellTags->{"Iterated Implication", "p2"}],
    Cell[18725, 590, 604, 14, 98, "Input",
      CellTags->{"Iterated Implication", "p4"}],
    Cell[20235, 636, 602, 14, 98, "Input",
      CellTags->{"Iterated Implication", "p5"}],
    Cell[20971, 657, 589, 13, 98, "Input",
      CellTags->"Iterated Implication"],
    Cell[21869, 687, 377, 9, 81, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal\[Dash]Reflexivity", 
        "Iterated Implication"}],
    Cell[22249, 698, 501, 13, 85, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal Symmetry", "Equal\[Dash]Symmetry", 
        "Iterated Implication"}],
    Cell[22753, 713, 545, 13, 85, "Input",
      CellTags->{
      "Equal Transitivity", "Equal\[Dash]Transitivity", 
        "Iterated Implication"}],
    Cell[24058, 751, 646, 15, 98, "Input",
      CellTags->{
      "Equal Transitivity \[Exists]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", "Iterated Implication"}],
    Cell[25501, 791, 776, 18, 92, "Input",
      CellTags->{
      "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
        "Equal\[Dash]Transitivity\[Dash]\[ForAll]", "Iterated Implication"}],
    Cell[27074, 834, 743, 20, 126, "Input",
      CellTags->{"Equal", "Equality", "Iterated Implication"}],
    Cell[27886, 861, 401, 9, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Irreflexivity", 
        "Less\[Dash]Irreflexivity"}],
    Cell[28290, 872, 515, 12, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Antisymmetry", 
        "Less\[Dash]Antisymmetry"}],
    Cell[29209, 899, 544, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Transitivity", 
        "Less\[Dash]Transitivity"}],
    Cell[30393, 933, 608, 15, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Transitivity \[Exists]", 
        "Less\[Dash]Transitivity\[Dash]\[Exists]"}],
    Cell[32758, 1002, 761, 21, 84, "Input",
      CellTags->{"Equality", "Iterated Implication", "Less"}],
    Cell[33598, 1030, 545, 13, 84, "Input",
      CellTags->{
      "Equal not Less", "equal\[Dash]not\[Dash]less", 
        "Equal\[Dash]not\[Dash]Less", "Iterated Implication"}],
    Cell[34146, 1045, 589, 14, 84, "Input",
      CellTags->{
      "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
        "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
        "Iterated Implication"}],
    Cell[35547, 1084, 547, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Totality", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Totality", "Less\[Dash]Totality"}],
    Cell[36097, 1099, 598, 15, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Transitivity", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Transitivity"}],
    Cell[36698, 1116, 594, 15, 84, "Input",
      CellTags->{
      "Equal and Less Transitivity", 
        "Equal\[Dash]and\[Dash]Less\[Dash]Transitivity", 
        "Iterated Implication"}],
    Cell[37295, 1133, 793, 21, 84, "Input",
      CellTags->{
      "Equal and Less", "Equality", "Equal versus Less", 
        "Iterated Implication"}],
    Cell[38091, 1156, 706, 19, 84, "Input",
      CellTags->{"Equal and Less", "Equality", "Iterated Implication"}],
    Cell[38873, 1182, 529, 13, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Def", "LessOrEqual\[Dash]Def"}],
    Cell[39405, 1197, 441, 11, 79, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Reflexivity", 
        "LessOrEqual\[Dash]Reflexivity"}],
    Cell[40689, 1233, 644, 14, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Antisymmetry", 
        "LessOrEqual\[Dash]antiSymmetry", "LessOrEqual\[Dash]Antisymmetry"}],
    Cell[42245, 1275, 642, 15, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Transitivity", 
        "LessOrEqual\[Dash]Transitivity"}],
    Cell[42890, 1292, 812, 20, 104, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual-Transitivity\[Dash]\[Exists]", 
        "LessOrEqual-Transitivity \[Exists]", 
        "LessOrEqual Transitivity \[Exists]"}],
    Cell[43705, 1314, 981, 26, 160, "Input",
      CellTags->{
      "Equal", "Equality", "Iterated Implication", "Transitivity"}],
    Cell[44761, 1347, 600, 14, 85, "Input",
      CellTags->{"Congruence Def by LessOrEqual", "Iterated Implication"}],
    Cell[45364, 1363, 375, 8, 81, "Input",
      CellTags->{"Congruence Reflexivity", "Iterated Implication"}],
    Cell[46510, 1395, 515, 12, 85, "Input",
      CellTags->{"Congruence Symmetry", "Iterated Implication"}],
    Cell[47549, 1425, 568, 12, 85, "Input",
      CellTags->{"Congruence Transitivity", "Iterated Implication"}]},
  "Sum of functions is commutative"->{
    Cell[7622, 256, 484, 12, 85, "Input",
      CellTags->{
      "Iterated Implication", "Sum of functions is commutative"}]},
  "Sum"->{
    Cell[8109, 270, 486, 12, 132, "Input",
      CellTags->{"Iterated Implication", "Sum"}]},
  "symmetric difference"->{
    Cell[10691, 356, 560, 13, 85, "Input",
      CellTags->{"Iterated Implication", "symmetric difference"}]},
  "associativity of symmetric difference"->{
    Cell[11254, 371, 639, 16, 68, "Input",
      CellTags->{
      "associativity of symmetric difference", 
        "associativity of symmetric difference right", 
        "Iterated Implication"}],
    Cell[12501, 408, 635, 16, 68, "Input",
      CellTags->{
      "associativity of symmetric difference", 
        "associativity of symmetric difference left", 
        "Iterated Implication"}]},
  "associativity of symmetric difference right"->{
    Cell[11254, 371, 639, 16, 68, "Input",
      CellTags->{
      "associativity of symmetric difference", 
        "associativity of symmetric difference right", 
        "Iterated Implication"}]},
  "associativity of symmetric difference left"->{
    Cell[12501, 408, 635, 16, 68, "Input",
      CellTags->{
      "associativity of symmetric difference", 
        "associativity of symmetric difference left", 
        "Iterated Implication"}]},
  "ForAll Distributivity"->{
    Cell[13437, 437, 547, 12, 98, "Input",
      CellTags->{"ForAll Distributivity", "Quantifier Distributivity"}],
    Cell[21563, 672, 165, 4, 42, "Input",
      CellTags->"ForAll Distributivity"]},
  "Quantifier Distributivity"->{
    Cell[13437, 437, 547, 12, 98, "Input",
      CellTags->{"ForAll Distributivity", "Quantifier Distributivity"}]},
  "Exists Distributivity"->{
    Cell[14802, 476, 446, 10, 98, "Input",
      CellTags->{"D", "Exists Distributivity"}]},
  "p1"->{
    Cell[15932, 507, 529, 12, 98, "Input",
      CellTags->{"Iterated Implication", "p1"}]},
  "p2"->{
    Cell[16772, 532, 536, 12, 104, "Input",
      CellTags->{"Iterated Implication", "p2"}]},
  "p"->{
    Cell[17631, 557, 591, 14, 98, "Input",
      CellTags->{"p", "p3", "Peirce Implication"}]},
  "p3"->{
    Cell[17631, 557, 591, 14, 98, "Input",
      CellTags->{"p", "p3", "Peirce Implication"}]},
  "Peirce Implication"->{
    Cell[17631, 557, 591, 14, 98, "Input",
      CellTags->{"p", "p3", "Peirce Implication"}]},
  "p4"->{
    Cell[18725, 590, 604, 14, 98, "Input",
      CellTags->{"Iterated Implication", "p4"}]},
  "p5"->{
    Cell[20235, 636, 602, 14, 98, "Input",
      CellTags->{"Iterated Implication", "p5"}]},
  "Equal Reflexivity"->{
    Cell[21869, 687, 377, 9, 81, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal\[Dash]Reflexivity", 
        "Iterated Implication"}],
    Cell[22249, 698, 501, 13, 85, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal Symmetry", "Equal\[Dash]Symmetry", 
        "Iterated Implication"}]},
  "Equal\[Dash]Reflexivity"->{
    Cell[21869, 687, 377, 9, 81, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal\[Dash]Reflexivity", 
        "Iterated Implication"}]},
  "Equal Symmetry"->{
    Cell[22249, 698, 501, 13, 85, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal Symmetry", "Equal\[Dash]Symmetry", 
        "Iterated Implication"}]},
  "Equal\[Dash]Symmetry"->{
    Cell[22249, 698, 501, 13, 85, "Input",
      CellTags->{
      "Equal Reflexivity", "Equal Symmetry", "Equal\[Dash]Symmetry", 
        "Iterated Implication"}]},
  "Equal Transitivity"->{
    Cell[22753, 713, 545, 13, 85, "Input",
      CellTags->{
      "Equal Transitivity", "Equal\[Dash]Transitivity", 
        "Iterated Implication"}]},
  "Equal\[Dash]Transitivity"->{
    Cell[22753, 713, 545, 13, 85, "Input",
      CellTags->{
      "Equal Transitivity", "Equal\[Dash]Transitivity", 
        "Iterated Implication"}],
    Cell[24058, 751, 646, 15, 98, "Input",
      CellTags->{
      "Equal Transitivity \[Exists]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", "Iterated Implication"}],
    Cell[25501, 791, 776, 18, 92, "Input",
      CellTags->{
      "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
        "Equal\[Dash]Transitivity\[Dash]\[ForAll]", 
        "Iterated Implication"}]},
  "Equal Transitivity \[Exists]"->{
    Cell[24058, 751, 646, 15, 98, "Input",
      CellTags->{
      "Equal Transitivity \[Exists]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
        "Iterated Implication"}]},
  "Equal\[Dash]Transitivity\[Dash]\[Exists]"->{
    Cell[24058, 751, 646, 15, 98, "Input",
      CellTags->{
      "Equal Transitivity \[Exists]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", "Iterated Implication"}],
    Cell[25501, 791, 776, 18, 92, "Input",
      CellTags->{
      "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
        "Equal\[Dash]Transitivity\[Dash]\[ForAll]", 
        "Iterated Implication"}]},
  "Equal Transitivity \[ForAll]"->{
    Cell[25501, 791, 776, 18, 92, "Input",
      CellTags->{
      "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
        "Equal\[Dash]Transitivity\[Dash]\[ForAll]", 
        "Iterated Implication"}]},
  "Equal\[Dash]Transitivity\[Dash]\[ForAll]"->{
    Cell[25501, 791, 776, 18, 92, "Input",
      CellTags->{
      "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
        "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
        "Equal\[Dash]Transitivity\[Dash]\[ForAll]", 
        "Iterated Implication"}]},
  "Equal"->{
    Cell[27074, 834, 743, 20, 126, "Input",
      CellTags->{"Equal", "Equality", "Iterated Implication"}],
    Cell[43705, 1314, 981, 26, 160, "Input",
      CellTags->{
      "Equal", "Equality", "Iterated Implication", "Transitivity"}]},
  "Equality"->{
    Cell[27074, 834, 743, 20, 126, "Input",
      CellTags->{"Equal", "Equality", "Iterated Implication"}],
    Cell[32758, 1002, 761, 21, 84, "Input",
      CellTags->{"Equality", "Iterated Implication", "Less"}],
    Cell[37295, 1133, 793, 21, 84, "Input",
      CellTags->{
      "Equal and Less", "Equality", "Equal versus Less", 
        "Iterated Implication"}],
    Cell[38091, 1156, 706, 19, 84, "Input",
      CellTags->{"Equal and Less", "Equality", "Iterated Implication"}],
    Cell[43705, 1314, 981, 26, 160, "Input",
      CellTags->{
      "Equal", "Equality", "Iterated Implication", "Transitivity"}]},
  "Less Irreflexivity"->{
    Cell[27886, 861, 401, 9, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Irreflexivity", 
        "Less\[Dash]Irreflexivity"}]},
  "Less\[Dash]Irreflexivity"->{
    Cell[27886, 861, 401, 9, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Irreflexivity", 
        "Less\[Dash]Irreflexivity"}]},
  "Less Antisymmetry"->{
    Cell[28290, 872, 515, 12, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Antisymmetry", 
        "Less\[Dash]Antisymmetry"}]},
  "Less\[Dash]Antisymmetry"->{
    Cell[28290, 872, 515, 12, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Antisymmetry", 
        "Less\[Dash]Antisymmetry"}]},
  "Less Transitivity"->{
    Cell[29209, 899, 544, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Transitivity", 
        "Less\[Dash]Transitivity"}]},
  "Less\[Dash]Transitivity"->{
    Cell[29209, 899, 544, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Transitivity", 
        "Less\[Dash]Transitivity"}]},
  "Less Transitivity \[Exists]"->{
    Cell[30393, 933, 608, 15, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Transitivity \[Exists]", 
        "Less\[Dash]Transitivity\[Dash]\[Exists]"}]},
  "Less\[Dash]Transitivity\[Dash]\[Exists]"->{
    Cell[30393, 933, 608, 15, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less Transitivity \[Exists]", 
        "Less\[Dash]Transitivity\[Dash]\[Exists]"}],
    Cell[31414, 963, 594, 15, 84, "Input",
      CellTags->"Less\[Dash]Transitivity\[Dash]\[Exists]"]},
  "Less"->{
    Cell[32758, 1002, 761, 21, 84, "Input",
      CellTags->{"Equality", "Iterated Implication", "Less"}]},
  "Equal not Less"->{
    Cell[33598, 1030, 545, 13, 84, "Input",
      CellTags->{
      "Equal not Less", "equal\[Dash]not\[Dash]less", 
        "Equal\[Dash]not\[Dash]Less", "Iterated Implication"}]},
  "equal\[Dash]not\[Dash]less"->{
    Cell[33598, 1030, 545, 13, 84, "Input",
      CellTags->{
      "Equal not Less", "equal\[Dash]not\[Dash]less", 
        "Equal\[Dash]not\[Dash]Less", "Iterated Implication"}],
    Cell[34146, 1045, 589, 14, 84, "Input",
      CellTags->{
      "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
        "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
        "Iterated Implication"}]},
  "Equal\[Dash]not\[Dash]Less"->{
    Cell[33598, 1030, 545, 13, 84, "Input",
      CellTags->{
      "Equal not Less", "equal\[Dash]not\[Dash]less", 
        "Equal\[Dash]not\[Dash]Less", "Iterated Implication"}],
    Cell[34146, 1045, 589, 14, 84, "Input",
      CellTags->{
      "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
        "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
        "Iterated Implication"}]},
  "Equal not Greater"->{
    Cell[34146, 1045, 589, 14, 84, "Input",
      CellTags->{
      "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
        "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
        "Iterated Implication"}]},
  "Equal\[Dash]not\[Dash]Greater"->{
    Cell[34146, 1045, 589, 14, 84, "Input",
      CellTags->{
      "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
        "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
        "Iterated Implication"}]},
  "Less and Equal Totality"->{
    Cell[35547, 1084, 547, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Totality", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Totality", 
        "Less\[Dash]Totality"}]},
  "Less\[Dash]and\[Dash]Equal\[Dash]Totality"->{
    Cell[35547, 1084, 547, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Totality", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Totality", 
        "Less\[Dash]Totality"}]},
  "Less\[Dash]Totality"->{
    Cell[35547, 1084, 547, 13, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Totality", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Totality", 
        "Less\[Dash]Totality"}]},
  "Less and Equal Transitivity"->{
    Cell[36097, 1099, 598, 15, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Transitivity", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Transitivity"}]},
  "Less\[Dash]and\[Dash]Equal\[Dash]Transitivity"->{
    Cell[36097, 1099, 598, 15, 84, "Input",
      CellTags->{
      "Iterated Implication", "Less and Equal Transitivity", 
        "Less\[Dash]and\[Dash]Equal\[Dash]Transitivity"}]},
  "Equal and Less Transitivity"->{
    Cell[36698, 1116, 594, 15, 84, "Input",
      CellTags->{
      "Equal and Less Transitivity", 
        "Equal\[Dash]and\[Dash]Less\[Dash]Transitivity", 
        "Iterated Implication"}]},
  "Equal\[Dash]and\[Dash]Less\[Dash]Transitivity"->{
    Cell[36698, 1116, 594, 15, 84, "Input",
      CellTags->{
      "Equal and Less Transitivity", 
        "Equal\[Dash]and\[Dash]Less\[Dash]Transitivity", 
        "Iterated Implication"}]},
  "Equal and Less"->{
    Cell[37295, 1133, 793, 21, 84, "Input",
      CellTags->{
      "Equal and Less", "Equality", "Equal versus Less", 
        "Iterated Implication"}],
    Cell[38091, 1156, 706, 19, 84, "Input",
      CellTags->{"Equal and Less", "Equality", "Iterated Implication"}]},
  "Equal versus Less"->{
    Cell[37295, 1133, 793, 21, 84, "Input",
      CellTags->{
      "Equal and Less", "Equality", "Equal versus Less", 
        "Iterated Implication"}]},
  "LessOrEqual Def"->{
    Cell[38873, 1182, 529, 13, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Def", "LessOrEqual\[Dash]Def"}]},
  "LessOrEqual\[Dash]Def"->{
    Cell[38873, 1182, 529, 13, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Def", "LessOrEqual\[Dash]Def"}]},
  "LessOrEqual Reflexivity"->{
    Cell[39405, 1197, 441, 11, 79, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Reflexivity", 
        "LessOrEqual\[Dash]Reflexivity"}]},
  "LessOrEqual\[Dash]Reflexivity"->{
    Cell[39405, 1197, 441, 11, 79, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Reflexivity", 
        "LessOrEqual\[Dash]Reflexivity"}]},
  "LessOrEqual Antisymmetry"->{
    Cell[40689, 1233, 644, 14, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Antisymmetry", 
        "LessOrEqual\[Dash]antiSymmetry", 
        "LessOrEqual\[Dash]Antisymmetry"}]},
  "LessOrEqual\[Dash]antiSymmetry"->{
    Cell[40689, 1233, 644, 14, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Antisymmetry", 
        "LessOrEqual\[Dash]antiSymmetry", 
        "LessOrEqual\[Dash]Antisymmetry"}]},
  "LessOrEqual\[Dash]Antisymmetry"->{
    Cell[40689, 1233, 644, 14, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Antisymmetry", 
        "LessOrEqual\[Dash]antiSymmetry", 
        "LessOrEqual\[Dash]Antisymmetry"}]},
  "LessOrEqual Transitivity"->{
    Cell[42245, 1275, 642, 15, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Transitivity", 
        "LessOrEqual\[Dash]Transitivity"}]},
  "LessOrEqual\[Dash]Transitivity"->{
    Cell[42245, 1275, 642, 15, 82, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual Transitivity", 
        "LessOrEqual\[Dash]Transitivity"}]},
  "LessOrEqual-Transitivity\[Dash]\[Exists]"->{
    Cell[42890, 1292, 812, 20, 104, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual-Transitivity\[Dash]\[Exists]", 
        "LessOrEqual-Transitivity \[Exists]", 
        "LessOrEqual Transitivity \[Exists]"}]},
  "LessOrEqual-Transitivity \[Exists]"->{
    Cell[42890, 1292, 812, 20, 104, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual-Transitivity\[Dash]\[Exists]", 
        "LessOrEqual-Transitivity \[Exists]", 
        "LessOrEqual Transitivity \[Exists]"}]},
  "LessOrEqual Transitivity \[Exists]"->{
    Cell[42890, 1292, 812, 20, 104, "Input",
      CellTags->{
      "Iterated Implication", "LessOrEqual-Transitivity\[Dash]\[Exists]", 
        "LessOrEqual-Transitivity \[Exists]", 
        "LessOrEqual Transitivity \[Exists]"}]},
  "Transitivity"->{
    Cell[43705, 1314, 981, 26, 160, "Input",
      CellTags->{
      "Equal", "Equality", "Iterated Implication", "Transitivity"}]},
  "Congruence Def by LessOrEqual"->{
    Cell[44761, 1347, 600, 14, 85, "Input",
      CellTags->{"Congruence Def by LessOrEqual", "Iterated Implication"}]},
  "Congruence Reflexivity"->{
    Cell[45364, 1363, 375, 8, 81, "Input",
      CellTags->{"Congruence Reflexivity", "Iterated Implication"}]},
  "Congruence Symmetry"->{
    Cell[46510, 1395, 515, 12, 85, "Input",
      CellTags->{"Congruence Symmetry", "Iterated Implication"}]},
  "Congruence Transitivity"->{
    Cell[47549, 1425, 568, 12, 85, "Input",
      CellTags->{"Congruence Transitivity", "Iterated Implication"}]},
  "2-ary limit"->{
    Cell[49588, 1485, 463, 12, 92, "Input",
      CellTags->"2-ary limit"],
    Cell[50054, 1499, 486, 12, 92, "Input",
      CellTags->{"2-ary limit", "3-ary limit"}],
    Cell[50543, 1513, 704, 15, 92, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[52493, 1564, 553, 14, 68, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
        "sum of sequences"}],
    Cell[58309, 1734, 362, 9, 104, "Input",
      CellTags->"2-ary limit"]},
  "3-ary limit"->{
    Cell[50054, 1499, 486, 12, 92, "Input",
      CellTags->{"2-ary limit", "3-ary limit"}],
    Cell[50543, 1513, 704, 15, 92, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[52493, 1564, 553, 14, 68, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
        "sum of sequences"}],
    Cell[55540, 1655, 353, 9, 104, "Input",
      CellTags->"3-ary limit"]},
  "4-ary limit"->{
    Cell[50543, 1513, 704, 15, 92, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[52493, 1564, 553, 14, 68, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
        "sum of sequences"}],
    Cell[53049, 1580, 446, 11, 155, "Input",
      CellTags->"4-ary limit"]},
  "sum of sequences"->{
    Cell[51289, 1532, 411, 11, 68, "Input",
      CellTags->"sum of sequences"],
    Cell[52493, 1564, 553, 14, 68, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
        "sum of sequences"}]},
  "distance of sum"->{
    Cell[51703, 1545, 787, 17, 68, "Input",
      CellTags->"distance of sum"],
    Cell[52493, 1564, 553, 14, 68, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
        "sum of sequences"}]},
  "max"->{
    Cell[52493, 1564, 553, 14, 68, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
        "sum of sequences"}]},
  "2-ary limit of sum"->{
    Cell[53545, 1595, 482, 13, 101, "Input",
      CellTags->"2-ary limit of sum"],
    Cell[58674, 1745, 499, 12, 124, "Input",
      CellTags->"2-ary limit of sum"]},
  "4-ary limit of sum"->{
    Cell[54199, 1615, 618, 13, 124, "Input",
      CellTags->"4-ary limit of sum"]},
  "3-ary limit of sum"->{
    Cell[55896, 1666, 570, 12, 124, "Input",
      CellTags->"3-ary limit of sum"]},
  "3-ary limit of sum: variant"->{
    Cell[57701, 1718, 605, 14, 124, "Input",
      CellTags->"3-ary limit of sum: variant"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"D", 60372, 1795},
  {"Iterated Implication", 60556, 1800},
  {"Sum of functions is commutative", 66279, 1927},
  {"Sum", 66418, 1931},
  {"symmetric difference", 66540, 1934},
  {"associativity of symmetric difference", 66696, 1937},
  {"associativity of symmetric difference right", 67145, 1948},
  {"associativity of symmetric difference left", 67395, 1954},
  {"ForAll Distributivity", 67623, 1960},
  {"Quantifier Distributivity", 67857, 1965},
  {"Exists Distributivity", 68003, 1968},
  {"p1", 68106, 1971},
  {"p2", 68209, 1974},
  {"p", 68312, 1977},
  {"p3", 68418, 1980},
  {"Peirce Implication", 68540, 1983},
  {"p4", 68646, 1986},
  {"p5", 68749, 1989},
  {"Equal Reflexivity", 68867, 1992},
  {"Equal\[Dash]Reflexivity", 69213, 2001},
  {"Equal Symmetry", 69385, 2006},
  {"Equal\[Dash]Symmetry", 69579, 2011},
  {"Equal Transitivity", 69771, 2016},
  {"Equal\[Dash]Transitivity", 69956, 2021},
  {"Equal Transitivity \[Exists]", 70619, 2036},
  {"Equal\[Dash]Transitivity\[Dash]\[Exists]", 70883, 2042},
  {"Equal Transitivity \[ForAll]", 71394, 2053},
  {"Equal\[Dash]Transitivity\[Dash]\[ForAll]", 71711, 2060},
  {"Equal", 71993, 2067},
  {"Equality", 72250, 2073},
  {"Less Irreflexivity", 72895, 2087},
  {"Less\[Dash]Irreflexivity", 73079, 2092},
  {"Less Antisymmetry", 73256, 2097},
  {"Less\[Dash]Antisymmetry", 73438, 2102},
  {"Less Transitivity", 73614, 2107},
  {"Less\[Dash]Transitivity", 73796, 2112},
  {"Less Transitivity \[Exists]", 73982, 2117},
  {"Less\[Dash]Transitivity\[Dash]\[Exists]", 74206, 2122},
  {"Less", 74498, 2129},
  {"Equal not Less", 74628, 2132},
  {"equal\[Dash]not\[Dash]less", 74844, 2137},
  {"Equal\[Dash]not\[Dash]Less", 75286, 2147},
  {"Equal not Greater", 75719, 2157},
  {"Equal\[Dash]not\[Dash]Greater", 75983, 2163},
  {"Less and Equal Totality", 76241, 2169},
  {"Less\[Dash]and\[Dash]Equal\[Dash]Totality", 76498, 2175},
  {"Less\[Dash]Totality", 76733, 2181},
  {"Less and Equal Transitivity", 76976, 2187},
  {"Less\[Dash]and\[Dash]Equal\[Dash]Transitivity", 77213, 2192},
  {"Equal and Less Transitivity", 77432, 2197},
  {"Equal\[Dash]and\[Dash]Less\[Dash]Transitivity", 77678, 2203},
  {"Equal and Less", 77893, 2209},
  {"Equal versus Less", 78190, 2216},
  {"LessOrEqual Def", 78368, 2221},
  {"LessOrEqual\[Dash]Def", 78536, 2225},
  {"LessOrEqual Reflexivity", 78706, 2229},
  {"LessOrEqual\[Dash]Reflexivity", 78907, 2234},
  {"LessOrEqual Antisymmetry", 79103, 2239},
  {"LessOrEqual\[Dash]antiSymmetry", 79350, 2245},
  {"LessOrEqual\[Dash]Antisymmetry", 79597, 2251},
  {"LessOrEqual Transitivity", 79838, 2257},
  {"LessOrEqual\[Dash]Transitivity", 80042, 2262},
  {"LessOrEqual-Transitivity\[Dash]\[Exists]", 80256, 2267},
  {"LessOrEqual-Transitivity \[Exists]", 80532, 2273},
  {"LessOrEqual Transitivity \[Exists]", 80808, 2279},
  {"Transitivity", 81062, 2285},
  {"Congruence Def by LessOrEqual", 81232, 2289},
  {"Congruence Reflexivity", 81383, 2292},
  {"Congruence Symmetry", 81523, 2295},
  {"Congruence Transitivity", 81665, 2298},
  {"2-ary limit", 81799, 2301},
  {"3-ary limit", 82342, 2314},
  {"4-ary limit", 82809, 2325},
  {"sum of sequences", 83189, 2334},
  {"distance of sum", 83464, 2341},
  {"max", 83726, 2348},
  {"2-ary limit of sum", 83923, 2353},
  {"4-ary limit of sum", 84118, 2358},
  {"3-ary limit of sum", 84229, 2361},
  {"3-ary limit of sum: variant", 84349, 2364}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 150, "Title"],

Cell[CellGroupData[{
Cell[1810, 55, 56, 0, 64, "Subsection"],
Cell[1869, 57, 578, 9, 146, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2484, 71, 38, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[2547, 75, 51, 1, 42, "Input"],
Cell[2601, 78, 183, 3, 58, "Print"]
}, Open  ]],
Cell[2799, 84, 181, 6, 46, "Text"],
Cell[2983, 92, 75, 1, 42, "Input"],
Cell[3061, 95, 71, 0, 46, "Text"],
Cell[3135, 97, 61, 1, 42, "Input"],
Cell[3199, 100, 119, 3, 46, "Text"],
Cell[3321, 105, 82, 1, 42, "Input"],
Cell[3406, 108, 77, 1, 42, "Input"],
Cell[3486, 111, 56, 0, 46, "Text"],
Cell[3545, 113, 68, 1, 42, "Input"],
Cell[3616, 116, 65, 1, 42, "Input"],
Cell[3684, 119, 65, 1, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3786, 125, 66, 0, 45, "Section"],
Cell[3855, 127, 120, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[4000, 134, 57, 1, 42, "Input"],
Cell[4060, 137, 401, 7, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4498, 149, 45, 1, 42, "Input"],
Cell[4546, 152, 401, 7, 88, "Output"]
}, Open  ]],
Cell[4962, 162, 97, 2, 46, "Text"],

Cell[CellGroupData[{
Cell[5084, 168, 31, 0, 64, "Subsection"],
Cell[5118, 170, 62, 0, 46, "Text"],
Cell[5183, 172, 182, 4, 71, "Text"],
Cell[5368, 178, 365, 9, 58, "Input",
  CellTags->"D"],
Cell[5736, 189, 56, 1, 42, "Input"],
Cell[5795, 192, 197, 4, 46, "Text"],
Cell[5995, 198, 98, 2, 42, "Input"],
Cell[6096, 202, 198, 4, 46, "Text"],
Cell[6297, 208, 85, 2, 46, "Text"],
Cell[6385, 212, 38, 0, 46, "Text"],
Cell[6426, 214, 245, 4, 71, "Text"],
Cell[6674, 220, 124, 3, 46, "Text"],
Cell[6801, 225, 38, 0, 46, "Text"],
Cell[6842, 227, 232, 7, 46, "Text"],
Cell[7077, 236, 219, 7, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7333, 248, 36, 0, 38, "Subsection"],
Cell[7372, 250, 247, 4, 71, "Text"],
Cell[7622, 256, 484, 12, 85, "Input",
  CellTags->{"Iterated Implication", "Sum of functions is commutative"}],
Cell[8109, 270, 486, 12, 132, "Input",
  CellTags->{"Iterated Implication", "Sum"}],
Cell[8598, 284, 425, 13, 42, "Input"],
Cell[9026, 299, 201, 4, 46, "Text"],
Cell[9230, 305, 117, 3, 46, "Text"],
Cell[9350, 310, 495, 14, 68, "Input"],
Cell[9848, 326, 200, 4, 46, "Text"],
Cell[10051, 332, 403, 8, 96, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10503, 346, 41, 0, 45, "Section"],
Cell[10547, 348, 65, 1, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10649, 354, 39, 0, 45, "Section"],
Cell[10691, 356, 560, 13, 85, "Input",
  CellTags->{"Iterated Implication", "symmetric difference"}],
Cell[11254, 371, 639, 16, 68, "Input",
  CellTags->{
  "associativity of symmetric difference", 
    "associativity of symmetric difference right", "Iterated Implication"}],
Cell[11896, 389, 393, 11, 42, "Input"],
Cell[12292, 402, 206, 4, 46, "Text"],
Cell[12501, 408, 635, 16, 68, "Input",
  CellTags->{
  "associativity of symmetric difference", 
    "associativity of symmetric difference left", "Iterated Implication"}],
Cell[13139, 426, 205, 4, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13381, 435, 53, 0, 45, "Section"],
Cell[13437, 437, 547, 12, 98, "Input",
  CellTags->{"ForAll Distributivity", "Quantifier Distributivity"}],
Cell[13987, 451, 154, 4, 42, "Input"],
Cell[14144, 457, 254, 5, 68, "Input"],
Cell[14401, 464, 197, 4, 46, "Text"],
Cell[14601, 470, 198, 4, 42, "Input"],
Cell[14802, 476, 446, 10, 98, "Input",
  CellTags->{"D", "Exists Distributivity"}],
Cell[15251, 488, 76, 1, 42, "Input"],
Cell[15330, 491, 198, 3, 68, "Input"],
Cell[15531, 496, 198, 3, 68, "Input"],
Cell[15732, 501, 197, 4, 46, "Text"],
Cell[15932, 507, 529, 12, 98, "Input",
  CellTags->{"Iterated Implication", "p1"}],
Cell[16464, 521, 128, 3, 41, "Input"],
Cell[16595, 526, 174, 4, 41, "Input"],
Cell[16772, 532, 536, 12, 104, "Input",
  CellTags->{"Iterated Implication", "p2"}],
Cell[17311, 546, 128, 3, 41, "Input"],
Cell[17442, 551, 186, 4, 42, "Input"],
Cell[17631, 557, 591, 14, 98, "Input",
  CellTags->{"p", "p3", "Peirce Implication"}],
Cell[18225, 573, 128, 3, 42, "Input"],
Cell[18356, 578, 189, 4, 46, "Text"],
Cell[18548, 584, 174, 4, 42, "Input"],
Cell[18725, 590, 604, 14, 98, "Input",
  CellTags->{"Iterated Implication", "p4"}],
Cell[19332, 606, 128, 3, 42, "Input"],
Cell[19463, 611, 174, 4, 42, "Input"],
Cell[19640, 617, 223, 5, 42, "Input"],
Cell[19866, 624, 174, 4, 42, "Input"],
Cell[20043, 630, 189, 4, 46, "Text"],
Cell[20235, 636, 602, 14, 98, "Input",
  CellTags->{"Iterated Implication", "p5"}],
Cell[20840, 652, 128, 3, 42, "Input"],
Cell[20971, 657, 589, 13, 98, "Input",
  CellTags->"Iterated Implication"],
Cell[21563, 672, 165, 4, 42, "Input",
  CellTags->"ForAll Distributivity"]
}, Closed]],

Cell[CellGroupData[{
Cell[21765, 681, 46, 0, 45, "Section"],

Cell[CellGroupData[{
Cell[21836, 685, 30, 0, 60, "Subsubsection"],
Cell[21869, 687, 377, 9, 81, "Input",
  CellTags->{
  "Equal Reflexivity", "Equal\[Dash]Reflexivity", "Iterated Implication"}],
Cell[22249, 698, 501, 13, 85, "Input",
  CellTags->{
  "Equal Reflexivity", "Equal Symmetry", "Equal\[Dash]Symmetry", 
    "Iterated Implication"}],
Cell[22753, 713, 545, 13, 85, "Input",
  CellTags->{
  "Equal Transitivity", "Equal\[Dash]Transitivity", "Iterated Implication"}],
Cell[23301, 728, 184, 5, 42, "Input"],
Cell[23488, 735, 287, 5, 96, "Text"],
Cell[23778, 742, 277, 7, 42, "Input"],
Cell[24058, 751, 646, 15, 98, "Input",
  CellTags->{
  "Equal Transitivity \[Exists]", "Equal\[Dash]Transitivity", 
    "Equal\[Dash]Transitivity\[Dash]\[Exists]", "Iterated Implication"}],
Cell[24707, 768, 590, 15, 68, "Input"],
Cell[25300, 785, 198, 4, 46, "Text"],
Cell[25501, 791, 776, 18, 92, "Input",
  CellTags->{
  "Equal Transitivity \[ForAll]", "Equal\[Dash]Transitivity", 
    "Equal\[Dash]Transitivity\[Dash]\[Exists]", 
    "Equal\[Dash]Transitivity\[Dash]\[ForAll]", "Iterated Implication"}],
Cell[26280, 811, 590, 15, 68, "Input"],
Cell[26873, 828, 198, 4, 46, "Text"],
Cell[27074, 834, 743, 20, 126, "Input",
  CellTags->{"Equal", "Equality", "Iterated Implication"}]
}, Closed]],

Cell[CellGroupData[{
Cell[27854, 859, 29, 0, 37, "Subsubsection"],
Cell[27886, 861, 401, 9, 84, "Input",
  CellTags->{
  "Iterated Implication", "Less Irreflexivity", "Less\[Dash]Irreflexivity"}],
Cell[28290, 872, 515, 12, 84, "Input",
  CellTags->{
  "Iterated Implication", "Less Antisymmetry", "Less\[Dash]Antisymmetry"}],
Cell[28808, 886, 398, 11, 84, "Input"],
Cell[29209, 899, 544, 13, 84, "Input",
  CellTags->{
  "Iterated Implication", "Less Transitivity", "Less\[Dash]Transitivity"}],
Cell[29756, 914, 634, 17, 84, "Input"],
Cell[30393, 933, 608, 15, 84, "Input",
  CellTags->{
  "Iterated Implication", "Less Transitivity \[Exists]", 
    "Less\[Dash]Transitivity\[Dash]\[Exists]"}],
Cell[31004, 950, 407, 11, 84, "Input"],
Cell[31414, 963, 594, 15, 84, "Input",
  CellTags->"Less\[Dash]Transitivity\[Dash]\[Exists]"],
Cell[32011, 980, 293, 8, 84, "Input"],
Cell[32307, 990, 448, 10, 84, "Input"],
Cell[32758, 1002, 761, 21, 84, "Input",
  CellTags->{"Equality", "Iterated Implication", "Less"}]
}, Closed]],

Cell[CellGroupData[{
Cell[33556, 1028, 39, 0, 37, "Subsubsection"],
Cell[33598, 1030, 545, 13, 84, "Input",
  CellTags->{
  "Equal not Less", "equal\[Dash]not\[Dash]less", 
    "Equal\[Dash]not\[Dash]Less", "Iterated Implication"}],
Cell[34146, 1045, 589, 14, 84, "Input",
  CellTags->{
  "Equal not Greater", "Equal\[Dash]not\[Dash]Greater", 
    "equal\[Dash]not\[Dash]less", "Equal\[Dash]not\[Dash]Less", 
    "Iterated Implication"}],
Cell[34738, 1061, 806, 21, 84, "Input"],
Cell[35547, 1084, 547, 13, 84, "Input",
  CellTags->{
  "Iterated Implication", "Less and Equal Totality", 
    "Less\[Dash]and\[Dash]Equal\[Dash]Totality", "Less\[Dash]Totality"}],
Cell[36097, 1099, 598, 15, 84, "Input",
  CellTags->{
  "Iterated Implication", "Less and Equal Transitivity", 
    "Less\[Dash]and\[Dash]Equal\[Dash]Transitivity"}],
Cell[36698, 1116, 594, 15, 84, "Input",
  CellTags->{
  "Equal and Less Transitivity", 
    "Equal\[Dash]and\[Dash]Less\[Dash]Transitivity", 
    "Iterated Implication"}],
Cell[37295, 1133, 793, 21, 84, "Input",
  CellTags->{
  "Equal and Less", "Equality", "Equal versus Less", 
    "Iterated Implication"}],
Cell[38091, 1156, 706, 19, 84, "Input",
  CellTags->{"Equal and Less", "Equality", "Iterated Implication"}]
}, Closed]],

Cell[CellGroupData[{
Cell[38834, 1180, 36, 0, 37, "Subsubsection"],
Cell[38873, 1182, 529, 13, 82, "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Def", "LessOrEqual\[Dash]Def"}],
Cell[39405, 1197, 441, 11, 79, "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Reflexivity", 
    "LessOrEqual\[Dash]Reflexivity"}],
Cell[39849, 1210, 837, 21, 91, "Input"],
Cell[40689, 1233, 644, 14, 82, "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Antisymmetry", 
    "LessOrEqual\[Dash]antiSymmetry", "LessOrEqual\[Dash]Antisymmetry"}],
Cell[41336, 1249, 906, 24, 91, "Input"],
Cell[42245, 1275, 642, 15, 82, "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual Transitivity", 
    "LessOrEqual\[Dash]Transitivity"}],
Cell[42890, 1292, 812, 20, 104, "Input",
  CellTags->{
  "Iterated Implication", "LessOrEqual-Transitivity\[Dash]\[Exists]", 
    "LessOrEqual-Transitivity \[Exists]", 
    "LessOrEqual Transitivity \[Exists]"}],
Cell[43705, 1314, 981, 26, 160, "Input",
  CellTags->{"Equal", "Equality", "Iterated Implication", "Transitivity"}]
}, Closed]],

Cell[CellGroupData[{
Cell[44723, 1345, 35, 0, 37, "Subsubsection"],
Cell[44761, 1347, 600, 14, 85, "Input",
  CellTags->{"Congruence Def by LessOrEqual", "Iterated Implication"}],
Cell[45364, 1363, 375, 8, 81, "Input",
  CellTags->{"Congruence Reflexivity", "Iterated Implication"}],
Cell[45742, 1373, 765, 20, 94, "Input"],
Cell[46510, 1395, 515, 12, 85, "Input",
  CellTags->{"Congruence Symmetry", "Iterated Implication"}],
Cell[47028, 1409, 518, 14, 68, "Input"],
Cell[47549, 1425, 568, 12, 85, "Input",
  CellTags->{"Congruence Transitivity", "Iterated Implication"}],
Cell[48120, 1439, 904, 22, 94, "Input"],
Cell[49027, 1463, 198, 4, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49274, 1473, 37, 0, 45, "Section"],
Cell[49314, 1475, 163, 3, 71, "Text"],
Cell[49480, 1480, 105, 3, 46, "Text"],
Cell[49588, 1485, 463, 12, 92, "Input",
  CellTags->"2-ary limit"],
Cell[50054, 1499, 486, 12, 92, "Input",
  CellTags->{"2-ary limit", "3-ary limit"}],
Cell[50543, 1513, 704, 15, 92, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
Cell[51250, 1530, 36, 0, 46, "Text"],
Cell[51289, 1532, 411, 11, 68, "Input",
  CellTags->"sum of sequences"],
Cell[51703, 1545, 787, 17, 68, "Input",
  CellTags->"distance of sum"],
Cell[52493, 1564, 553, 14, 68, "Input",
  CellTags->{
  "2-ary limit", "3-ary limit", "4-ary limit", "distance of sum", "max", 
    "sum of sequences"}],
Cell[53049, 1580, 446, 11, 155, "Input",
  CellTags->"4-ary limit"],
Cell[53498, 1593, 44, 0, 46, "Text"],
Cell[53545, 1595, 482, 13, 101, "Input",
  CellTags->"2-ary limit of sum"],
Cell[54030, 1610, 166, 3, 73, "Text"],
Cell[54199, 1615, 618, 13, 124, "Input",
  CellTags->"4-ary limit of sum"],

Cell[CellGroupData[{
Cell[54842, 1632, 298, 7, 66, "Input"],
Cell[55143, 1641, 128, 2, 41, "Output"]
}, Open  ]],
Cell[55286, 1646, 194, 4, 47, "Text"],
Cell[55483, 1652, 54, 1, 41, "Input"],
Cell[55540, 1655, 353, 9, 104, "Input",
  CellTags->"3-ary limit"],
Cell[55896, 1666, 570, 12, 124, "Input",
  CellTags->"3-ary limit of sum"],
Cell[56469, 1680, 346, 7, 66, "Input"],
Cell[56818, 1689, 44, 1, 41, "Input"],
Cell[56865, 1692, 194, 4, 47, "Text"],
Cell[57062, 1698, 333, 8, 66, "Input"],
Cell[57398, 1708, 99, 2, 41, "Input"],
Cell[57500, 1712, 198, 4, 47, "Text"],
Cell[57701, 1718, 605, 14, 124, "Input",
  CellTags->"3-ary limit of sum: variant"],
Cell[58309, 1734, 362, 9, 104, "Input",
  CellTags->"2-ary limit"],
Cell[58674, 1745, 499, 12, 124, "Input",
  CellTags->"2-ary limit of sum"],
Cell[59176, 1759, 298, 7, 66, "Input"],
Cell[59477, 1768, 194, 4, 47, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

